package com.ynet.life.file.parser;

import com.lowagie.text.BadElementException;
import com.lowagie.text.Cell;
import com.lowagie.text.Document;
import com.lowagie.text.Font;
import com.lowagie.text.Paragraph;
import com.lowagie.text.Table;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfWriter;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonDownloadPDFFileParser.class */
public class CommonDownloadPDFFileParser implements CommonDownloadFileParserInterface {
    @Override // com.ynet.life.file.parser.CommonDownloadFileParserInterface
    public byte[] writeToFile(List titles, List recordList, List outputFields, List outputFormats, List lastList, String filePathName, String encoding) throws TranFailException {
        try {
            Table table = new Table(outputFields.size());
            if (titles != null) {
                for (int i = 0; i < titles.size(); i++) {
                    String titleItem = (String) titles.get(i);
                    createCell(table, titleItem);
                }
            }
            Iterator iterator = recordList.iterator();
            while (iterator.hasNext()) {
                Map record = (Map) iterator.next();
                for (int i2 = 0; i2 < outputFields.size(); i2++) {
                    String fieldId = (String) outputFields.get(i2);
                    String str = (String) record.get(fieldId);
                    String fieldValue = str;
                    if (str == null) {
                        fieldValue = "";
                    }
                    String format = (String) outputFormats.get(i2);
                    createCell(table, DownloadFileParserUtil.transformFormat(fieldValue, format));
                }
            }
            Document document = new Document();
            try {
                try {
                    PdfWriter.getInstance(document, new FileOutputStream(filePathName));
                    document.open();
                    document.add(table);
                    byte[] b = document.toString().getBytes();
                    if (b.length > 0) {
                        return b;
                    }
                    document.close();
                    return null;
                } catch (Exception e) {
                    Trace.logError("LifeFile", "下载文件出错", e);
                    throw new TranFailException("EBLN0000", "下载文件出错");
                }
            } finally {
                document.close();
            }
        } catch (BadElementException e2) {
            Trace.logError("LifeFile", "下载文件出错", e2);
            throw new TranFailException("EBLN0000", "下载文件出错");
        }
    }

    private void createCell(Table table, String content) {
        Cell cell = new Cell();
        try {
            BaseFont bf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", false);
            Font fontChinese = new Font(bf, 12.0f, 0);
            cell.add(new Paragraph(content, fontChinese));
        } catch (Exception e) {
            Trace.logError("LifeFile", "下载文件时中文出错", e);
        }
        table.addCell(cell);
    }
}
